@@ -8,7 +8,7 @@ from fiotclient.config import FiwareConfig
 
 
 def _log_request_url(method: str, url: str, params: dict):
-    params_str = '&'.join(map(lambda key, value: f'{key}={value}', params.items())) if params else ''
+    params_str = '&'.join(map(lambda key: f'{key}={params[key]}', params.keys())) if params else ''
     if params_str:
         logging.info(f"{method} {url}?{params_str}")
     else:
@@ -17,7 +17,7 @@ def _log_request_url(method: str, url: str, params: dict):
 
 def _log_request(method, url, params, headers, str_payload):
     _log_request_url(method, url, params)
-    logging.debug(f"Headers: {json.dumps(headers, indent=4)}")
+    logging.debug(f"Headers: {headers}")
     if str_payload != '':
         logging.debug(f"Payload: {str_payload}")
 
